@@ -27,7 +27,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.50';
+our $VERSION = '0.51';
 
 
 # Preloaded methods go here.
@@ -136,9 +136,7 @@ Script::Toolbox - Framework for the daily business scripts
   File( 'path/to/file',   'append this to the file' );
   File( 'path/to/file',   $arrRef );           # append array elements 
   File( 'path/to/file',   $arrRef, $recSep );  # append array elements 
-
-                              # append key <$fldSep> value <$recSep>
-  File( 'path/to/file', $hashRef, $recSep, $fieldSep);
+  File( 'path/to/file',   $hashRef, $recSep, $fieldSep); # append key <$fldSep> value <$recSep>
   File( '| /bin/cat', 'Hello world.\n' );
 
   $fileHandle = TmpFile();                     # open new temporary file
@@ -238,8 +236,8 @@ Script::Toolbox - Framework for the daily business scripts
   my $jmp = $m->currJump  ('MainMenue'); # callback address of last seleted option
   my $val = $m->currValue ('MainMenue'); # data value of last seleted option
 
-
-
+  my $list= $m->getMatching('MainMenue','^[1]','number','label'); # return all labels where option number starts with one
+  my $list= $m->getMatching('MainMenue','(min|low)','value','number'); # return all option numbers where value match min or low
 
   #----------------
   # Data Menues 
@@ -323,7 +321,6 @@ value of the callback function. In case the callback function do not return
 anything, a reference to the input array of the callback function will be
 returned. The callback function may return one scalar value.
 
-Example:
  ...
  sub decrypt($) {...}
  $f = File('path/to/encrypted', \&decrypt);
@@ -431,7 +428,6 @@ If Now() is called with a diff argument it returns a hash ref with following key
 I<seconds minutes hours days DHMS>. Each corresponding value is the 
 difference between now and the given time value.
 
-    Example:
     my $d = Now( time()- 1800 );
     print $d->{'seconds'} .'s'; 	# 1800.0s
     print $d->{'minutes'} .'min';	# 30.0min
@@ -452,7 +448,6 @@ Read the directory like Dir() and make a stat() call for each matching file.
 Skip '.'  '..' and any entry not matching regexp.
 Return a reference to a hash or undef if directory not readable.
 
-	Example:
 	$d = Stat('/bin','echo');
 	print $d->{'echo'}{'atime'};
 	print $d->{'echo'}{'blksize'};
@@ -548,16 +543,104 @@ This is an object oriented container for regular menues. Each menue generated
 by Menues->new() gets a automatic RETURN option with option number zero and 
 must have a unique menue-name.
 
-Menue-Methods:
+Menues-Methods:
 
 =over 4
 
+=item addMenue(<menueDefs>)
+
+Add one or more complete menue definitions to the menues object. A <menueDefs> has this layout:
+{<menueName> => [<menueDef>], ...}
+
+<menueDef> is the structure of a simple menue as decribed in item Menue. In the context of
+Menues, a jump target may be also the name of a menue in the same Menues container.
+
+     $m->addMenue({
+         'SubMenue' =>[{'label'=>'Opt2'}, {'label'=>'Opt3'}],
+         'MainMenue'=>[{'label'=>'Go to submenue','jump'=>'SubMenue'}, {'label'=>'Opt1'}]
+     });
+
+=item addOption(<menueName>,<labelsDef>)
+
+Add a new option line to the menue <menueName>.
+
+     $m->addOption('MainMenue',  {'label'=>'Opt3',     'jump'=>\&callBack });
+     $m->addOption('MainMenue',  {'label'=>'Sub Menue','jump'=>'SubMenue1'}); 
+     $m->addOption('MainMenue',  {'label'=>'Edit Value','value'=>10});
+
+=item setHeader(<menueName>,<newHeaderStr>)
+
+Replace the header of the menue <menueName>. This override an enabled auto header.
+
+=item setFooter(<menueName>,<newFooterStr>)
+
+Replace the footer of the menue <menueName>. 
+
+=item run(<menueName>, [<maxRunCnt>])
+
+Start the menue <menueName>. The run() method returns after 
+the the user has <maxRunCnt> options selected. Default value for <maxRunCnt> is one.
+If <maxRunCnt> is lower than or equal zero, the run() method will never return unless the
+user selects the RETURN option (num=0). The run() method give back the number of the
+last selected option.
+
+
+    while( $m->run('MainMenue') ) { ... }
+    $num = $m->run('MainMenue', 3);
+    $num = $m->run('MainMenue', 0);
+
+=item currNumber(<menueName>)
+
+Get the number of the last selected option.
+
+  my $opt = $m->currNumber('MainMenue'); # number of last seleted option
+
+=item currLabel(<menueName>)
+
+Get the label of the last selected option.
+
+  my $lbl = $m->currLabel ('MainMenue'); # label  of last seleted option
+
+=item currJump(<menueName>)
+
+Get the address of the callback function of the last selected option.
+
+  my $jmp = $m->currJump  ('MainMenue'); # callback address of last seleted option
+
+=item currValue(<menueName>)
+
+Get the data field value of the last selected option.
+
+  my $val = $m->currValue ('MainMenue'); # data value of last seleted option
+
+=item getMatching(<menueName>,<pattern>,<searchIn>,<return>)
+
+Search in the options array of menue named <menueName>. Return the reference
+to an array with return values according to matches.
+
+=over 2
+
+=item <pattern>
+
+A regular expression.
+
+=item <searchIn>
+
+The part of option to search in (label,number,value).
+
+=item <return>
+
+The part of option to return (label,number,value) if search match.
+
+=back
+
+
+
 =item setAutoHeader(), setAutoHeader(<menueName>)
 
-If Autoheader is enabled, an automatic header line
-will be generated for all menues or only the one selected by <menueName>.
-
- 'Menue: <menueName>' 
+Enable automatic header line generation if no regular header defined.
+The header looks like 'Menue: <menueName>' 
+Enable AutoHeader for all menues or only the one selected by <menueName>.
 
 =item delAutoHeader(), delAutoHeader(<menueName>)
 
@@ -576,8 +659,10 @@ The edited values will be returned. Acceptable input are the same array with
 In case of simple scalar input an optional hash with 'header' and/or 'footer'
 keys may be given as second parameter.
 An option entry like:
+
  {'label'=>'Read Only Example', 'value'=>10, 'readOnly'=>1}
-causes the value will be displayed only.
+
+causes the value will be displayed only and can not be changed.
 
 =back
 
