@@ -236,6 +236,7 @@ sub run($$){
     return      if( ! defined $self->{'def'}{$name} );
     $cnt = 1    if( ! defined $cnt);
     $cnt = 1    if( $cnt !~ /^[-]?\d+$/ );
+    $cnt =-1    if( $cnt == 0 );
     my $o; my $m;
     while($cnt--) {
         my $p   = $self->_getParams($name);
@@ -280,6 +281,47 @@ sub currJump($){
     return;
 }
 
+#------------------------------------------------------------------------------
+#------------------------------------------------------------------------------
+sub _invalidParam($$$$$){
+    my ($self,$name,$pattern,$search,$return) = @_;
+    return  1  if( !defined $pattern );
+    return  1  if( !defined $search  );
+    return  1  if( !defined $return  );
+    return  1  if( !defined $self->{'def'}{$name}{'opts'});
+    return  1  if( $search !~ /(number|value|label)/ );
+    return  1  if( $return !~ /(number|value|label)/ );
+    return  0;
+}
+
+#------------------------------------------------------------------------------
+# Search the labels array for $pattern matching in $search. If matching return
+# value of type return.
+# $pattern='[Mm]ax' $search='value' $return='label'
+# => returns all labels where value column matching Max or max.
+# search: /(label,number,value)/
+# return: /(label,number,value)/
+#------------------------------------------------------------------------------
+sub getMatching($$$$){
+    my ($self,$name,$pattern,$search,$return) = @_;
+    return '' if( _invalidParam($self,$name,$pattern,$search,$return));
+
+    my $L = $self->{'def'}{$name}{'opts'};
+    my @R;
+    my $i=1;
+    foreach my $l ( @{$L} ){
+        if( $search eq 'number' ){
+            push @R, $l->{$return}  if( $i =~ /$pattern/);
+            $i++;
+        }else{
+            next    if( !defined $l->{$search} );
+            next    if( $l->{$search} !~ /$pattern/ );
+            push @R, $l->{$return};
+        }
+    }
+    return \@R;
+}
+
 
 1;
 __END__
